@@ -7,7 +7,7 @@ Created on Thu Mar 21 20:57:51 2019
 """
 
 
-import psutil,argparse,sys
+import argparse,sys
 
 import numpy as np
 import linecache
@@ -410,24 +410,6 @@ def arg_parser(args):
     return (args)
 
 
-
-
-def ram():
-    '''
-    Determine the current RAM usage by the process
-    '''
-    py = psutil.Process(os.getpid())
-    return round(py.memory_info()[0]/2.**30,2)
-
-
-
-
-
-
-
-
-
-
 if __name__ == "__main__":
     args = arg_parser(sys.argv[1:])
     inputs=args.input
