@@ -193,7 +193,10 @@ def cli_main():
 
     if tools[2]:
         print("\n\n***************************3. eCAMI start***************************************************\n\n")
+        print("Using "+args.eCAMI_kmer_db+" db in eCAMI")
+        # exit(0)
         ecami_config = eCAMI_config(
+            db_type = args.eCAMI_kmer_db,
             input = f"{outPath}uniInput",
             output= f"{outPath}eCAMI.out",
             k_mer = args.eCAMI_k_mer,
